summaryrefslogtreecommitdiffstats
path: root/tests/arthur
diff options
context:
space:
mode:
authoraavit <qt-info@nokia.com>2011-01-13 14:21:33 (GMT)
committeraavit <qt-info@nokia.com>2011-01-13 14:21:33 (GMT)
commit1287c134594cbb173857e62229eccefbefd2d412 (patch)
tree3bba291a94de1c9de136c4812398d0abb7c056e5 /tests/arthur
parent85d70109688ff5e189de57712bb169e71303f614 (diff)
downloadQt-1287c134594cbb173857e62229eccefbefd2d412.zip
Qt-1287c134594cbb173857e62229eccefbefd2d412.tar.gz
Qt-1287c134594cbb173857e62229eccefbefd2d412.tar.bz2
Small improvements to host mapping and mismatch report
Diffstat (limited to 'tests/arthur')
-rw-r--r--tests/arthur/baselineserver/src/baselineserver.cpp13
-rw-r--r--tests/arthur/baselineserver/src/report.cpp5
2 files changed, 10 insertions, 8 deletions
diff --git a/tests/arthur/baselineserver/src/report.cpp b/tests/arthur/baselineserver/src/report.cpp
index 505fd62..c85f144 100644
--- a/tests/arthur/baselineserver/src/report.cpp
+++ b/tests/arthur/baselineserver/src/report.cpp
@@ -138,8 +138,9 @@ void Report::writeHeader()
QString title = plat.value(PI_TestCase) + QLS(" Qt Baseline Test Report");
out << "<head><title>" << title << "</title></head>\n"
<< "<html><body><h1>" << title << "</h1>\n"
- << "<p>Run Id: <b>" << runId << "</b></p>\n"
- << "<p>Summary: <b>" << numMismatches << " of " << numItems << "</b> items reported mismatching</p>\n\n";
+ << "<p>Note: This is a <i>static</i> page, generated at " << QDateTime::currentDateTime().toString()
+ << " for the test run with id " << runId << "</p>\n"
+ << "<p>Summary: <b><span style=\"color:red\">" << numMismatches << " of " << numItems << "</b></span> items reported mismatching</p>\n\n";
out << "<h3>Platform Info:</h3>\n"
<< "<table>\n";
foreach (QString key, plat.keys())
diff --git a/tests/arthur/baselineserver/src/baselineserver.cpp b/tests/arthur/baselineserver/src/baselineserver.cpp
index 64b50fd..d72f2e3 100644
--- a/tests/arthur/baselineserver/src/baselineserver.cpp
+++ b/tests/arthur/baselineserver/src/baselineserver.cpp
@@ -348,9 +348,8 @@ void BaselineHandler::mapPlatformInfo() const
if (host.isEmpty() || host == QLS("localhost")) {
host = plat.value(PI_HostAddress);
} else {
- //# Site specific, should be in a config file
- if (!host.startsWith(QLS("oldhcp"))) {
- // remove index postfix typical of vm hostnames
+ if (!plat.value(PI_PulseGitBranch).isEmpty()) {
+ // i.e. pulse run, so remove index postfix typical of vm hostnames
host.remove(QRegExp(QLS("\\d+$")));
if (host.endsWith(QLC('-')))
host.chop(1);
@@ -366,7 +365,7 @@ void BaselineHandler::mapPlatformInfo() const
// Map Qt version
QString ver = plat.value(PI_QtVersion);
- mapped.insert(PI_QtVersion, ver.prepend(QLS("Qt-"))); //### TBD: remove patch version
+ mapped.insert(PI_QtVersion, ver.prepend(QLS("Qt-")));
}
QString BaselineHandler::pathForItem(const ImageItem &item, bool isBaseline, bool absolute) const
@@ -479,7 +478,8 @@ void BaselineHandler::testPathMapping()
<< QLS("macbuilder-02.test.troll.no")
<< QLS("bqvm1164")
<< QLS("chimera")
- << QLS("localhost");
+ << QLS("localhost")
+ << QLS("");
ImageItem item;
item.testFunction = QLS("testPathMapping");
@@ -489,7 +489,8 @@ void BaselineHandler::testPathMapping()
plat.insert(PI_QtVersion, QLS("4.8.0"));
plat.insert(PI_BuildKey, QLS("(nobuildkey)"));
- plat.insert(PI_QMakeSpec, "linux-g++");
+ plat.insert(PI_QMakeSpec, QLS("linux-g++"));
+ plat.insert(PI_PulseGitBranch, QLS("somebranch"));
foreach(const QString& host, hosts) {
mapped.clear();
plat.insert(PI_HostName, host);